# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [2.3.13](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.12...rattler_virtual_packages-v2.3.13) - 2026-03-18

### Fixed

- *(virtual_packages)* handle invalid chars in LibC family ([#2209](https://github.com/conda/rattler/pull/2209))

## [2.3.12](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.11...rattler_virtual_packages-v2.3.12) - 2026-03-16

### Other

- updated the following local packages: rattler_conda_types

## [2.3.11](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.10...rattler_virtual_packages-v2.3.11) - 2026-02-25

### Other

- updated the following local packages: rattler_conda_types

## [2.3.10](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.9...rattler_virtual_packages-v2.3.10) - 2026-02-20

### Other

- updated the following local packages: rattler_conda_types

## [2.3.9](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.8...rattler_virtual_packages-v2.3.9) - 2026-02-19

### Other

- Typo and clippy fixes ([#2047](https://github.com/conda/rattler/pull/2047))

## [2.3.8](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.7...rattler_virtual_packages-v2.3.8) - 2026-02-04

### Other

- updated the following local packages: rattler_conda_types

## [2.3.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.6...rattler_virtual_packages-v2.3.7) - 2026-01-22

### Other

- updated the following local packages: rattler_conda_types

## [2.3.6](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v2.3.5...rattler_virtual_packages-v2.3.6) - 2026-01-22

### Fixed

- changelog

## [2.3.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.4...rattler_virtual_packages-v2.3.5) - 2026-01-22

### Other

- rename `loong64` to `loongarch64` ([#1957](https://github.com/conda/rattler/pull/1957))

## [2.3.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.3...rattler_virtual_packages-v2.3.4) - 2025-12-18

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [2.3.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.2...rattler_virtual_packages-v2.3.3) - 2025-12-08

### Other

- updated the following local packages: rattler_conda_types

## [2.3.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.1...rattler_virtual_packages-v2.3.2) - 2025-11-27

### Other

- updated the following local packages: rattler_conda_types

## [2.3.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.3.0...rattler_virtual_packages-v2.3.1) - 2025-11-25

### Other

- update Cargo.toml dependencies

## [2.3.0](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.8...rattler_virtual_packages-v2.3.0) - 2025-11-22

### Added

- improve libc detection using `gnu_get_libc_version()` ([#1868](https://github.com/conda/rattler/pull/1868))

## [2.2.8](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.7...rattler_virtual_packages-v2.2.8) - 2025-11-20

### Other

- updated the following local packages: rattler_conda_types

## [2.2.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.6...rattler_virtual_packages-v2.2.7) - 2025-11-19

### Other

- updated the following local packages: rattler_conda_types

## [2.2.6](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.5...rattler_virtual_packages-v2.2.6) - 2025-11-13

### Other

- updated the following local packages: rattler_conda_types

## [2.2.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.4...rattler_virtual_packages-v2.2.5) - 2025-10-28

### Other

- updated the following local packages: rattler_conda_types

## [2.2.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.3...rattler_virtual_packages-v2.2.4) - 2025-10-18

### Other

- updated the following local packages: rattler_conda_types

## [2.2.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.2...rattler_virtual_packages-v2.2.3) - 2025-10-17

### Other

- updated the following local packages: rattler_conda_types

## [2.2.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.1...rattler_virtual_packages-v2.2.2) - 2025-10-14

### Other

- updated the following local packages: rattler_conda_types

## [2.2.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.2.0...rattler_virtual_packages-v2.2.1) - 2025-10-08

### Fixed

- use defaults found on OS even if cross-compiling ([#1713](https://github.com/conda/rattler/pull/1713))

## [2.2.0](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.7...rattler_virtual_packages-v2.2.0) - 2025-10-07

### Added

- add cross-platform detection and tests ([#1708](https://github.com/conda/rattler/pull/1708))

## [2.1.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.6...rattler_virtual_packages-v2.1.7) - 2025-10-03

### Other

- updated the following local packages: rattler_conda_types

## [2.1.6](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.5...rattler_virtual_packages-v2.1.6) - 2025-09-30

### Other

- updated the following local packages: rattler_conda_types

## [2.1.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.4...rattler_virtual_packages-v2.1.5) - 2025-09-05

### Other

- updated the following local packages: rattler_conda_types

## [2.1.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.3...rattler_virtual_packages-v2.1.4) - 2025-09-02

### Other

- updated the following local packages: rattler_conda_types

## [2.1.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.2...rattler_virtual_packages-v2.1.3) - 2025-08-15

### Other

- updated the following local packages: rattler_conda_types

## [2.1.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.1...rattler_virtual_packages-v2.1.2) - 2025-08-12

### Other

- updated the following local packages: rattler_conda_types

## [2.1.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.1.0...rattler_virtual_packages-v2.1.1) - 2025-07-23

### Other

- updated the following local packages: rattler_conda_types

## [2.1.0](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.19...rattler_virtual_packages-v2.1.0) - 2025-07-21

### Added

- make `Platform` `non_exhaustive` ([#1539](https://github.com/conda/rattler/pull/1539))
- add support for loong64 platform to rattler ([#1534](https://github.com/conda/rattler/pull/1534))

## [2.0.19](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.18...rattler_virtual_packages-v2.0.19) - 2025-07-14

### Other

- updated the following local packages: rattler_conda_types

## [2.0.18](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.17...rattler_virtual_packages-v2.0.18) - 2025-07-09

### Other

- updated the following local packages: rattler_conda_types

## [2.0.17](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.16...rattler_virtual_packages-v2.0.17) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [2.0.16](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.15...rattler_virtual_packages-v2.0.16) - 2025-06-26

### Other

- updated the following local packages: rattler_conda_types

## [2.0.15](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.14...rattler_virtual_packages-v2.0.15) - 2025-06-25

### Other

- updated the following local packages: rattler_conda_types

## [2.0.14](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.13...rattler_virtual_packages-v2.0.14) - 2025-06-23

### Fixed

- fix code to use nom 8

### Other

- *(ci)* Update Rust crate nom to v8 ([#1404](https://github.com/conda/rattler/pull/1404))
- Revert "fix code to use nom 8"
- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [2.0.13](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.12...rattler_virtual_packages-v2.0.13) - 2025-05-23

### Other

- updated the following local packages: rattler_conda_types

## [2.0.12](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.11...rattler_virtual_packages-v2.0.12) - 2025-05-16

### Other

- update Cargo.toml dependencies

## [2.0.11](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.10...rattler_virtual_packages-v2.0.11) - 2025-05-03

### Other

- lock workspace member dependencies ([#1279](https://github.com/conda/rattler/pull/1279))

## [2.0.10](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.9...rattler_virtual_packages-v2.0.10) - 2025-04-10

### Other

- update Cargo.toml dependencies

## [2.0.9](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.8...rattler_virtual_packages-v2.0.9) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [2.0.8](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.7...rattler_virtual_packages-v2.0.8) - 2025-03-14

### Other

- updated the following local packages: rattler_conda_types

## [2.0.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.6...rattler_virtual_packages-v2.0.7) - 2025-03-10

### Other

- release ([#1137](https://github.com/conda/rattler/pull/1137))

## [2.0.6](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.5...rattler_virtual_packages-v2.0.6) - 2025-02-28

### Other

- update Cargo.toml dependencies

## [2.0.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.4...rattler_virtual_packages-v2.0.5) - 2025-02-27

### Other

- updated the following local packages: rattler_conda_types

## [2.0.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.3...rattler_virtual_packages-v2.0.4) - 2025-02-25

### Other

- updated the following local packages: rattler_conda_types

## [2.0.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.2...rattler_virtual_packages-v2.0.3) - 2025-02-18

### Fixed

- do not try to call `ldd` on non-linux systems (#1064)

## [2.0.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.1...rattler_virtual_packages-v2.0.2) - 2025-02-06

### Other

- updated the following local packages: rattler_conda_types

## [2.0.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v2.0.0...rattler_virtual_packages-v2.0.1) - 2025-02-03

### Other

- updated the following local packages: rattler_conda_types

## [2.0.0](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.2.0...rattler_virtual_packages-v2.0.0) - 2025-01-23

### Added

- align with upcoming virtual package cep (#1028)
- add linux-ppc (PPC32 BE) platform to rattler (#1024)

## [1.2.0](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.17...rattler_virtual_packages-v1.2.0) - 2025-01-09

### Added

- Match GenericVirtualPackage with MatchSpec (#1016)

## [1.1.17](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.16...rattler_virtual_packages-v1.1.17) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types

## [1.1.16](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.15...rattler_virtual_packages-v1.1.16) - 2025-01-08

### Other

- updated the following local packages: rattler_conda_types

## [1.1.15](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.14...rattler_virtual_packages-v1.1.15) - 2024-12-20

### Other

- updated the following local packages: rattler_conda_types

## [1.1.14](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.13...rattler_virtual_packages-v1.1.14) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [1.1.13](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.12...rattler_virtual_packages-v1.1.13) - 2024-12-13

### Other

- updated the following local packages: rattler_conda_types

## [1.1.12](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.11...rattler_virtual_packages-v1.1.12) - 2024-12-12

### Other
- updated the following local packages: rattler_conda_types

## [1.1.11](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.10...rattler_virtual_packages-v1.1.11) - 2024-11-30

### Other

- updated the following local packages: rattler_conda_types

## [1.1.10](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.9...rattler_virtual_packages-v1.1.10) - 2024-11-18

### Other

- updated the following local packages: rattler_conda_types

## [1.1.9](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.8...rattler_virtual_packages-v1.1.9) - 2024-11-14

### Other

- updated the following local packages: rattler_conda_types

## [1.1.8](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.7...rattler_virtual_packages-v1.1.8) - 2024-11-04

### Other

- release ([#903](https://github.com/conda/rattler/pull/903))

## [1.1.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.6...rattler_virtual_packages-v1.1.7) - 2024-10-07

### Other

- add snapshot tests to verify solver sorting order ([#895](https://github.com/conda/rattler/pull/895))

## [1.1.6](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.5...rattler_virtual_packages-v1.1.6) - 2024-10-03

### Other

- updated the following local packages: rattler_conda_types

## [1.1.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.4...rattler_virtual_packages-v1.1.5) - 2024-09-23

### Other

- updated the following local packages: rattler_conda_types

## [1.1.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.3...rattler_virtual_packages-v1.1.4) - 2024-09-09

### Other

- updated the following local packages: rattler_conda_types

## [1.1.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.2...rattler_virtual_packages-v1.1.3) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [1.1.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.1...rattler_virtual_packages-v1.1.2) - 2024-09-03

### Fixed
- allow `gcs://` and `oci://` in gateway ([#845](https://github.com/conda/rattler/pull/845))

## [1.1.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.0...rattler_virtual_packages-v1.1.1) - 2024-09-03

### Other
- updated the following local packages: rattler_conda_types

## [1.1.0](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.0.4...rattler_virtual_packages-v1.1.0) - 2024-09-02

### Added
- start adding interface to override ([#834](https://github.com/conda/rattler/pull/834))
- Add support for `CONDA_OVERRIDE_CUDA` ([#818](https://github.com/conda/rattler/pull/818))

### Other
- make virtual package overrides none by default consistently ([#842](https://github.com/conda/rattler/pull/842))

## [1.0.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.0.3...rattler_virtual_packages-v1.0.4) - 2024-08-16

### Fixed
- detect solus glibc ([#821](https://github.com/conda/rattler/pull/821))

## [1.0.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.0.2...rattler_virtual_packages-v1.0.3) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [1.0.2](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v1.0.1...rattler_virtual_packages-v1.0.2) - 2024-08-06

### Other
- updated the following local packages: rattler_conda_types

## [1.0.1](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v1.0.0...rattler_virtual_packages-v1.0.1) - 2024-08-02

### Other
- updated the following local packages: rattler_conda_types

## [0.19.20](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.19...rattler_virtual_packages-v0.19.20) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.19.19](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.18...rattler_virtual_packages-v0.19.19) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.19.18](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.17...rattler_virtual_packages-v0.19.18) - 2024-07-16

### Fixed
- add gentoo support for glibc ([#779](https://github.com/conda/rattler/pull/779))

## [0.19.17](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.16...rattler_virtual_packages-v0.19.17) - 2024-07-15

### Other
- updated the following local packages: rattler_conda_types

## [0.19.16](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.15...rattler_virtual_packages-v0.19.16) - 2024-07-08

### Added
- add support for zos-z ([#753](https://github.com/conda/rattler/pull/753))

### Fixed
- run clippy on all targets ([#762](https://github.com/conda/rattler/pull/762))

## [0.19.15](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.19.14...rattler_virtual_packages-v0.19.15) - 2024-06-04

### Other
- updated the following local packages: rattler_conda_types

## [0.19.14](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.13...rattler_virtual_packages-v0.19.14) - 2024-06-03

### Other
- updated the following local packages: rattler_conda_types

## [0.19.13](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.12...rattler_virtual_packages-v0.19.13) - 2024-05-28

### Other
- updated the following local packages: rattler_conda_types

## [0.19.12](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.11...rattler_virtual_packages-v0.19.12) - 2024-05-27

### Other
- updated the following local packages: rattler_conda_types

## [0.19.11](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.10...rattler_virtual_packages-v0.19.11) - 2024-05-14

### Other
- updated the following local packages: rattler_conda_types

## [0.19.10](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.9...rattler_virtual_packages-v0.19.10) - 2024-05-13

### Other
- updated the following local packages: rattler_conda_types

## [0.19.9](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.8...rattler_virtual_packages-v0.19.9) - 2024-05-06

### Other
- updated the following local packages: rattler_conda_types

## [0.19.8](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.7...rattler_virtual_packages-v0.19.8) - 2024-04-25

### Other
- updated the following local packages: rattler_conda_types

## [0.19.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.6...rattler_virtual_packages-v0.19.7) - 2024-04-19

### Other
- update dependencies incl. reqwest ([#606](https://github.com/conda/rattler/pull/606))

## [0.19.6](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.19.5...rattler_virtual_packages-v0.19.6) - 2024-04-05

### Other
- updated the following local packages: rattler_conda_types

## [0.19.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.4...rattler_virtual_packages-v0.19.5) - 2024-03-30

### Added
- proper archspec detection using archspec-rs ([#584](https://github.com/conda/rattler/pull/584))

## [0.19.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.3...rattler_virtual_packages-v0.19.4) - 2024-03-21

### Other
- updated the following local packages: rattler_conda_types

## [0.19.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.2...rattler_virtual_packages-v0.19.3) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.1...rattler_virtual_packages-v0.19.2) - 2024-03-08

### Other
- updated the following local packages: rattler_conda_types

## [0.19.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.0...rattler_virtual_packages-v0.19.1) - 2024-03-06

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/conda/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.18.0...rattler_virtual_packages-v0.19.0) - 2024-02-26
